<?php
/*
  Plugin Name: Tickera - PDF invoice tickets addon
  Plugin URI: https://tickera.com
  Description: Shows attendees' info / ticket(s) on the PDF invoice
  Author: Tickera
  Author URI: https://tickera.com
  Version: 1.0
  TextDomain: tc
  Domain Path: /languages/

  Copyright 2019 Tickera (https://tickera.com)
 */
if (!defined('ABSPATH')) {
    exit;
} // Exit if accessed directly
if (!class_exists('TC_tickera_pdf_invoice_tickets_addon')) {

    class TC_tickera_pdf_invoice_tickets_addon {

        public $version = '1.0';
        public $title = 'Tickera - PDF invoice tickets addon';
        public $name = 'tickera_pdf_invoice_tickets_addon';
        public $dir_name = 'tickera_pdf_invoice_tickets_addon';
        public $location = 'plugins';
        public $plugin_dir = '';
        public $plugin_url = '';

        public function __construct() {
            $this->init_vars();
            add_action('wpo_wcpdf_after_order_details', array($this, 'tc_add_tickets_table_on_woo_order_details_page'), 10, 2);

            if (class_exists('TC')) {//Check if Tickera plugin is active / main Tickera class exists
                global $tc;
            }
        }

        public function init_vars() {
            //setup proper directories
            if (defined('WP_PLUGIN_URL') && defined('WP_PLUGIN_DIR') && file_exists(WP_PLUGIN_DIR . '/' . $this->dir_name . '/' . basename(__FILE__))) {
                $this->location = 'subfolder-plugins';
                $this->plugin_dir = WP_PLUGIN_DIR . '/' . $this->dir_name . '/';
                $this->plugin_url = plugins_url('/', __FILE__);
            } elseif (defined('WP_PLUGIN_URL') && defined('WP_PLUGIN_DIR') && file_exists(WP_PLUGIN_DIR . '/' . basename(__FILE__))) {
                $this->location = 'plugins';
                $this->plugin_dir = WP_PLUGIN_DIR . '/';
                $this->plugin_url = plugins_url('/', __FILE__);
            } elseif (is_multisite() && defined('WPMU_PLUGIN_URL') && defined('WPMU_PLUGIN_DIR') && file_exists(WPMU_PLUGIN_DIR . '/' . basename(__FILE__))) {
                $this->location = 'mu-plugins';
                $this->plugin_dir = WPMU_PLUGIN_DIR;
                $this->plugin_url = WPMU_PLUGIN_URL;
            } else {
                wp_die(sprintf(__('There was an issue determining where %s is installed. Please reinstall it.', 'tc'), $this->title));
            }
        }

        function tc_add_tickets_table_on_woo_order_details_page($template_type, $order) {
            if (is_int($order)) {
                $order_id = $order;
            } else {
                $order_id = method_exists($order, 'get_id') ? $order->get_id() : $order->id;
            }

            $wc_order = new WC_Order((int) $order_id);

            if (is_object($wc_order)) {
                if ($this->allowed_tickets_download($order)) {
                    $order_id = method_exists($order, 'get_id') ? $order->get_id() : $order->id;

                    tc_order_details_table_front($order_id);
                }
            }
        }

        function allowed_tickets_download($order) {

            $has_ticket = false;

            if (method_exists($order, 'get_items')) {
                $items = $order->get_items();
                if (empty($items)) {
                    $items = WC()->cart->get_cart();
                }
            } else {
                $items = WC()->cart->get_cart();
            }

            foreach ($items as $item) {
                $product_id = $item['product_id'];

                $is_ticket_meta = get_post_meta(TC_WooCommerce_Bridge::maybe_get_original_wpml_product_id($product_id), '_tc_is_ticket', true);
                $is_ticket = $is_ticket_meta == 'yes' ? true : false;
                if ($is_ticket) {
                    $has_ticket = true;
                }
            }

            if ($has_ticket) {

                $tc_general_settings = get_option('tc_general_setting', false);

                $tc_woo_allow_cash_on_delivery_processing = isset($tc_general_settings['tc_woo_allow_cash_on_delivery_processing']) ? $tc_general_settings['tc_woo_allow_cash_on_delivery_processing'] : 'no';

                $allowed_tickets_download = true;

                if (is_object($order)) {

                    $order_id = method_exists($order, 'get_id') ? $order->get_id() : $order->id;
                    $order_payment_method = get_post_meta($order_id, '_payment_method', true);

                    if ($order->get_status() == 'processing' || $order->get_status() == 'completed') {
                        $allowed_tickets_download = true;
                        if ($order_payment_method == 'cod') {//if payment gateway is Cash on Delivery
                            if ($tc_woo_allow_cash_on_delivery_processing == 'yes') {//If the processing payment status is allowed
                                $allowed_tickets_download = true; //Allow tickets download and sending
                            } else {
                                if ($order->get_status() == 'completed') {//If the order status is completed allow download anyway
                                    $allowed_tickets_download = true;
                                } else {
                                    $allowed_tickets_download = false; //disallow download if it's processed and $tc_woo_allow_cash_on_delivery_processing is no
                                }
                            }
                        }
                    } else {
                        $allowed_tickets_download = false;
                    }
                }
            } else {
                $allowed_tickets_download = false;
            }

            return apply_filters('tc_allow_tickets_download', $allowed_tickets_download, $order);
        }

    }

}

$TC_tickera_pdf_invoice_tickets_addon = new TC_tickera_pdf_invoice_tickets_addon();
